# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector.api.contacts_api import ContactsApi  # noqa: E501


class TestContactsApi(unittest.IsolatedAsyncioTestCase):
    """ContactsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ContactsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_chat_api_contact_chat_get(self) -> None:
        """Test case for chat_api_contact_chat_get

        Contact Chat Get  # noqa: E501
        """
        pass

    async def test_chat_api_contact_chat_get_or_create(self) -> None:
        """Test case for chat_api_contact_chat_get_or_create

        Contact Chat Get Or Create  # noqa: E501
        """
        pass

    async def test_chat_api_contact_get(self) -> None:
        """Test case for chat_api_contact_get

        Contact Get  # noqa: E501
        """
        pass

    async def test_chat_api_contacts_list(self) -> None:
        """Test case for chat_api_contacts_list

        Contacts List  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
