# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.response_wrapper_list_scheduled_message_get import ResponseWrapperListScheduledMessageGet  # noqa: E501

class TestResponseWrapperListScheduledMessageGet(unittest.TestCase):
    """ResponseWrapperListScheduledMessageGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperListScheduledMessageGet:
        """Test ResponseWrapperListScheduledMessageGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperListScheduledMessageGet`
        """
        model = ResponseWrapperListScheduledMessageGet()  # noqa: E501
        if include_optional:
            return ResponseWrapperListScheduledMessageGet(
                done = True,
                result = [
                    chat_server_connector.models.scheduled_message_get.ScheduledMessageGet(
                        id = 56, 
                        chat_id = 56, 
                        chat_member_id = 56, 
                        text = '', 
                        file_id = '', 
                        chat_message_type = 'TEXT', 
                        schedule_kind = 'ONCE', 
                        cron_expr = '', 
                        timezone = '', 
                        next_run_at = 56, 
                        status = 'ACTIVE', 
                        last_run_at = 56, 
                        last_error = '', 
                        created_at = 56, 
                        attachments = [
                            chat_server_connector.models.chat_message_attachment_read.ChatMessageAttachmentRead(
                                file_id = '', 
                                attachment_type = 'IMAGE', 
                                id = 56, )
                            ], )
                    ],
                error = ''
            )
        else:
            return ResponseWrapperListScheduledMessageGet(
                done = True,
        )
        """

    def testResponseWrapperListScheduledMessageGet(self):
        """Test ResponseWrapperListScheduledMessageGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
