# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.response_wrapper_chat_session_get import ResponseWrapperChatSessionGet  # noqa: E501

class TestResponseWrapperChatSessionGet(unittest.TestCase):
    """ResponseWrapperChatSessionGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperChatSessionGet:
        """Test ResponseWrapperChatSessionGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperChatSessionGet`
        """
        model = ResponseWrapperChatSessionGet()  # noqa: E501
        if include_optional:
            return ResponseWrapperChatSessionGet(
                done = True,
                result = chat_server_connector.models.chat_session_get.ChatSessionGet(
                    id = 56, 
                    chat_id = 56, 
                    creator_id = 56, 
                    credentials = chat_server_connector.models.credentials.Credentials(), 
                    chat_session_type = 'TEXT', 
                    created_at = 56, 
                    ended_at = 56, 
                    last_activity_at = 56, ),
                error = ''
            )
        else:
            return ResponseWrapperChatSessionGet(
                done = True,
        )
        """

    def testResponseWrapperChatSessionGet(self):
        """Test ResponseWrapperChatSessionGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
