# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ScheduleKind(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    ONCE = 'ONCE'
    CRON = 'CRON'

    @classmethod
    def from_json(cls, json_str: str) -> ScheduleKind:
        """Create an instance of ScheduleKind from a JSON string"""
        return ScheduleKind(json.loads(json_str))


