# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictInt, StrictStr
from chat_server_connector.models.schedule_kind import ScheduleKind
from chat_server_connector.models.scheduled_message_status_update import ScheduledMessageStatusUpdate

class ScheduledMessagePatch(BaseModel):
    """
    ScheduledMessagePatch
    """
    text: Optional[StrictStr] = None
    file_id: Optional[StrictStr] = None
    status: Optional[ScheduledMessageStatusUpdate] = None
    schedule_kind: Optional[ScheduleKind] = None
    run_at: Optional[StrictInt] = None
    cron_expr: Optional[StrictStr] = None
    timezone: Optional[StrictStr] = None
    __properties = ["text", "file_id", "status", "schedule_kind", "run_at", "cron_expr", "timezone"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ScheduledMessagePatch:
        """Create an instance of ScheduledMessagePatch from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ScheduledMessagePatch:
        """Create an instance of ScheduledMessagePatch from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ScheduledMessagePatch.parse_obj(obj)

        _obj = ScheduledMessagePatch.parse_obj({
            "text": obj.get("text"),
            "file_id": obj.get("file_id"),
            "status": obj.get("status"),
            "schedule_kind": obj.get("schedule_kind"),
            "run_at": obj.get("run_at"),
            "cron_expr": obj.get("cron_expr"),
            "timezone": obj.get("timezone")
        })
        return _obj


