# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.scheduled_message_create import ScheduledMessageCreate  # noqa: E501

class TestScheduledMessageCreate(unittest.TestCase):
    """ScheduledMessageCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScheduledMessageCreate:
        """Test ScheduledMessageCreate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScheduledMessageCreate`
        """
        model = ScheduledMessageCreate()  # noqa: E501
        if include_optional:
            return ScheduledMessageCreate(
                text = '',
                file_id = '',
                chat_message_type = 'TEXT',
                attachments = [
                    chat_server_connector.models.chat_message_attachment_create.ChatMessageAttachmentCreate(
                        file_id = '', 
                        attachment_type = 'IMAGE', )
                    ],
                chat_session_id = 56,
                schedule_kind = 'ONCE',
                run_at = 56,
                cron_expr = '',
                timezone = ''
            )
        else:
            return ScheduledMessageCreate(
                schedule_kind = 'ONCE',
        )
        """

    def testScheduledMessageCreate(self):
        """Test ScheduledMessageCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
