# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ChatType(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    SOLO = 'SOLO'
    BOT = 'BOT'
    ONE_ON_ONE = 'ONE_ON_ONE'
    GROUP_PUBLIC = 'GROUP_PUBLIC'
    GROUP_PRIVATE = 'GROUP_PRIVATE'

    @classmethod
    def from_json(cls, json_str: str) -> ChatType:
        """Create an instance of ChatType from a JSON string"""
        return ChatType(json.loads(json_str))


