# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector.api.chat_settings_api import ChatSettingsApi  # noqa: E501


class TestChatSettingsApi(unittest.IsolatedAsyncioTestCase):
    """ChatSettingsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ChatSettingsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_chat_api_settings_get(self) -> None:
        """Test case for chat_api_settings_get

        Settings Get  # noqa: E501
        """
        pass

    async def test_chat_api_settings_set(self) -> None:
        """Test case for chat_api_settings_set

        Settings Set  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
